@@ -6,6 +6,9 @@ Command::Command()
     d_parent(0),
     d_homedirChar(Options::instance().homedirChar())
 {
+    imsg << "\n"
+            "Command\n";
+
     concatArgs();       // concatenate arguments, separating them by /
                         // characters
 
@@ -29,9 +32,14 @@ Command::Command()
     if (ArgConfig::instance().option('V'))
     {
         cerr << "Parent nr: " << d_parent << "\n"
-                "Action: " << s_action[d_action] << "\n"
-                "Initial characters of directories: ";
-        copy(begin(), end(), ostream_iterator<string>(cerr, " "));
+                "Action: " << s_action[d_action] << "\n";
+        if (empty())
+            cerr << "No initial directory specifier(s)";
+        else
+        {
+            cerr << "Initial characters of directories: ";
+            copy(begin(), end(), ostream_iterator<string>(cerr, " "));
+        }
         cerr << endl;
     }
 }
