@@ -2,8 +2,12 @@
 
 void Command::concatArgs()
 {
-    for(char const *arg: Options::instance().args())
+    auto ranger = Options::instance().args();
+
+    for (char const *arg: ranger)               // all arguments end in /
         (d_arguments += arg) += '/';
 
+    delete[] &*ranger.begin();
+
     imsg << "Arguments: `" << d_arguments << '\'' << endl;
 }
