@@ -18,7 +18,7 @@ void Command::determineAction()
             d_action = FROM_PARENT;
         break;
 
-        // other characters: 1st char. of directory or homedir char.
+        // other characters: 1st char. of directory or homedir char (~).
         default:
             if (ch == d_homedirChar)
             {
@@ -34,6 +34,6 @@ void Command::determineAction()
         d_arguments.erase(0, 1);      // remove the 1st (location) character
     while (d_arguments.front() == '/'); // and a possible initial / sep.
 
-    imsg << "Removed the location character: `" <<
+    imsg << "After removing the initial location/dir character(s): `" <<
                                             d_arguments << '\'' << endl;
 }
