@@ -1,14 +1,17 @@
 #include "history.ih"
 
+    // choice: chosen directory to cd to
+
 void History::save(string const &choice)
 {
-    if (d_name.empty())               // no history file in use
+    if (d_historyFilename.empty())               // no history file in use
         return;
 
-    ofstream out(d_name);
+    ofstream out(d_historyFilename);
     if (!out)
     {
-        imsg << "cannot write history file `" << d_name << '\'' << endl;
+        imsg << "cannot write history file `" << d_historyFilename << '\'' << 
+                                                                        endl;
         return;
     }
 
@@ -26,13 +29,7 @@ void History::save(string const &choice)
     sort(d_history.begin(), d_history.end(), compareTimes);
 //    stable_sort(d_history.begin(), d_history.end(), compareCounts);
 
-    string value;
-    size_t maxSize = d_arg.option(&value, "history-maxsize") ?
-                        A2x(value)
-                    :
-                        UINT_MAX;
-
-    if (maxSize != UINT_MAX)
+    if (size_t maxSize = d_options.historyMaxSize(); maxSize != UINT_MAX)
     {
         imsg << "Max. history size: " << maxSize << endl;
 
@@ -43,3 +40,4 @@ void History::save(string const &choice)
     copy(d_history.begin(), d_history.end(),
                                 ostream_iterator<HistoryInfo>(out, "\n"));
 }
+
