@@ -6,6 +6,9 @@ Selector::Action Selector::action(Block const &block)
 
     int ch = oneKey.get();                      // get the reply
 
+    imsg << "Selector::action received oneKey " << static_cast<char>(ch) << 
+                                                                        endl;
+
     if (accept(ch, s_inc, block.prompt))        // go to the next block
         return INC;
 
